*+
*+
*+    Source Module => D:\SRC\NGSRCHTM\PROFILE.PRG
*+
*+    Copyright (C) 1997, Phil Barnett. All Rights Reserved Worldwide.
*+
*+    Functions: Function ProfileString()
*+               Function ProfileNum()
*+               Function ProfileDate()
*+               Static Function init_profile()
*+
*+    Reformatted by Click! 2.02 on Jan-31-1999 at  9:24 pm
*+
*+

#include "COMMON.CH"

static INI_DATA := {}
static INI_NAME := ''

*+
*+
*+    Function ProfileString()
*+
*+    Called from ( ngsrchtm.prg )   8 - procedure ngsrchtm()
*+                ( profile.prg  )   1 - function profilenum()
*+                                   1 - function profiledate()
*+
*+
*+
function ProfileString( cFile, cSection, cKey, cDefault )

//
//  This function reads a string from the specified .INI file.
//
//  Parameters: cFile    - The .INI file name to be used
//              cSection - The section from which to read
//              cKey     - The key value for which to search
//              cDefault - The default value if not found (optional)
//
//     Returns: cString - The string read from the file.
//

local nSPointer := 0
local nKPointer := 0
local cString

default cDefault to ''
cString := cDefault

begin sequence

   if INI_NAME <> cFile
      if !init_profile( cFile )
         break
      endif
   endif

   cSection := upper( alltrim( cSection ) )
   cKey     := upper( alltrim( cKey ) )

   if left( cSection, 1 ) <> '['
      cSection := '[' + cSection
   endif

   if right( cSection, 1 ) <> ']'
      cSection += ']'
   endif

   nSPointer := ascan( INI_DATA, { | x | x[ 1 ] == cSection } )

   if !empty( nSPointer )
      nKPointer := ascan( INI_DATA[ nSPointer, 2 ], { | x | x[ 1 ] == cKey } )
      if !empty( nKPointer )
         cString := INI_DATA[ nSPointer, 2, nKPointer, 2 ]
      endif
   endif

end sequence

return cString

*+
*+
*+    Function ProfileNum()
*+
*+
*+
function ProfileNum( cFile, cSection, cKey, nDefault )

//
//  This function reads a number from the specified .INI file.
//
//  Parameters: cFile    - The .INI file name to be used
//              cSection - The section from which to read
//              cKey     - The key value for which to search
//              nDefault - The default value if not found (optional)
//
//     Returns: nValue - The numeric value read from the file.
//

local retval

default nDefault to 0
retval := nDefault

begin sequence

   if INI_NAME <> cFile
      if !init_profile( cFile )
         break
      endif
   endif

   retval := ProfileString( cFile, cSection, cKey, '' )

   if empty( retval )
      retval := nDefault
   else
      retval := val( retval )
   endif

end sequence

return retval

*+
*+
*+    Function ProfileDate()
*+
*+
*+
function ProfileDate( cFile, cSection, cKey, dDefault )

//
//  This function reads a date from the specified .INI file.
//
//  Parameters: cFile    - The .INI file name to be used
//              cSection - The section from which to read
//              cKey     - The key value for which to search
//              dDefault - The default date if not found (optional)
//
//     Returns: dDate - The date value read from the file.
//
local retval

default dDefault to ctod( '' )
retval := dDefault

begin sequence

   if INI_NAME <> cFile
      if !init_profile( cFile )
         break
      endif
   endif

   retval := ProfileString( cFile, cSection, cKey, '' )

   if empty( retval )
      retval := dDefault
   else
      retval := ctod( retval )
   endif

end sequence

return retval

/*
function SetProfile( cFile, cSection, cKey, xValue )
//
//  This function writes a value to the .INI file specified.
//
//  Parameters: cFile    - The .INI file name to be used
//              cSection - The section for which to search
//              cKey     - The key value for which to search
//              xValue   - The new value to be written
//
//     Returns: .T. if successful, .F. otherwise.
//

Remember: When implementing this section that init_profile() throws away
anything that is empty line, comment (//) and anything that is not
either a section header or a line with no = sign.

This means that this section absolutely cannot rely on init_profile()
and must have it's own file reader/writer

return lRetCode
*/

*+
*+
*+    Static Function init_profile()
*+
*+    Called from ( profile.prg  )   1 - function profilestring()
*+                                   1 - function profilenum()
*+                                   1 - function profiledate()
*+
*+
*+
static function init_profile( cFile )

local oBufObj       := bInit( cFile )
local retval        := bopen( oBufObj )
local cThisLine
local lFoundSection := .f.
local nLastElement  := 0
local eqat

INI_DATA := {}
INI_NAME := ''

if retval
   INI_NAME := cFile
   do while !bEof( oBufObj )

      cThisLine := alltrim( bReadLine( oBufObj ) )

      if empty( cThisLine ) .or. left( cThisLine, 2 ) == '//'
         loop
      endif

      if !lFoundSection
         if left( cThisLine, 1 ) == '[' .and. right( cThisLine, 1 ) == ']'
            lFoundSection := .t.
         else
            loop
         endif
      endif

      if left( cThisLine, 1 ) == '[' .and. right( cThisLine, 1 ) == ']'
         aadd( INI_DATA, { upper( cThisLine ), {} } )
         nLastElement ++
      else
         eqat := at( '=', cThisLine )
         if eqat > 0
            aadd( INI_DATA[ nLastElement, 2 ], ;
                  { upper( alltrim( left( cThisLine, eqat - 1 ) ) ), ;
                  substr( cThisLine, eqat + 1 ) } )
         endif
      endif
   enddo
   bClose( oBufObj )
endif

return retval

*+ EOF: PROFILE.PRG
